| Title: | Clinical Trial Data |
|---|---|
| Description: | Example clinical trial data sets formatted for easy use in R. |
| Authors: | Jeremy Wildfire [aut, cre], Renan Escalante Chong [aut] |
| Maintainer: | Jeremy Wildfire <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.0.0 |
| Built: | 2026-05-14 05:54:10 UTC |
| Source: | https://github.com/cran/safetyData |
ADaM adae data frame
adam_adaeadam_adae
a data frame with 1191 rows and 55 columns. See https://github.com/SafetyGraphics/safetyData/blob/main/data-raw/adam/README.md for more details and full data specification.
ADaM adlbc data frame
adam_adlbcadam_adlbc
a data frame with 74264 rows and 46 columns. See https://github.com/SafetyGraphics/safetyData/blob/main/data-raw/adam/README.md for more details and full data specification.
ADaM adlbh data frame
adam_adlbhadam_adlbh
a data frame with 49932 rows and 46 columns. See https://github.com/SafetyGraphics/safetyData/blob/main/data-raw/adam/README.md for more details and full data specification.
ADaM adlbhy data frame
adam_adlbhyadam_adlbhy
a data frame with 9954 rows and 43 columns. See https://github.com/SafetyGraphics/safetyData/blob/main/data-raw/adam/README.md for more details and full data specification.
ADaM adqsadas data frame
adam_adqsadasadam_adqsadas
a data frame with 12463 rows and 40 columns. See https://github.com/SafetyGraphics/safetyData/blob/main/data-raw/adam/README.md for more details and full data specification.
ADaM adqscibc data frame
adam_adqscibcadam_adqscibc
a data frame with 730 rows and 36 columns. See https://github.com/SafetyGraphics/safetyData/blob/main/data-raw/adam/README.md for more details and full data specification.
ADaM adqsnpix data frame
adam_adqsnpixadam_adqsnpix
a data frame with 31140 rows and 41 columns. See https://github.com/SafetyGraphics/safetyData/blob/main/data-raw/adam/README.md for more details and full data specification.
ADaM adsl data frame
adam_adsladam_adsl
a data frame with 254 rows and 48 columns. See https://github.com/SafetyGraphics/safetyData/blob/main/data-raw/adam/README.md for more details and full data specification.
ADaM adtte data frame
adam_adtteadam_adtte
a data frame with 254 rows and 26 columns. See https://github.com/SafetyGraphics/safetyData/blob/main/data-raw/adam/README.md for more details and full data specification.
ADaM advs data frame
adam_advsadam_advs
a data frame with 32139 rows and 34 columns. See https://github.com/SafetyGraphics/safetyData/blob/main/data-raw/adam/README.md for more details and full data specification.
Adverse Events data frame - One record per adverse event per subject
sdtm_aesdtm_ae
a data frame with 1191 rows and 35 columns. See https://github.com/SafetyGraphics/safetyData/blob/main/data-raw/sdtm/README.md for more details and full data specification. Columns:
STUDYID text - Study Identifier
DOMAIN text - Domain Abbreviation
USUBJID text - Unique Subject Identifier
AESEQ integer - Sequence Number
AESPID text - Sponsor-Defined Identifier
AETERM text - Reported Term for the Adverse Event
AELLT text - Lowest Level Term
AELLTCD integer - Lowest Level Term Code
AEDECOD text - Dictionary-Derived Term
AEPTCD integer - Preferred Term Code
AEHLT text - High Level Term
AEHLTCD integer - High Level Term Code
AEHLGT text - High Level Group Term
AEHLGTCD integer - High Level Group Term Code
AEBODSYS text - Body System or Organ Class
AEBDSYCD integer - Body System or Organ Class Code
AESOC text - Primary System Organ Class
AESOCCD integer - Primary System Organ Class Code
AESEV text - Severity/Intensity
AESER text - Serious Event
AEACN text - Action Taken with Study Treatment
AEREL text - Causality
AEOUT text - Outcome of Adverse Event
AESCAN text - Involves Cancer
AESCONG text - Congenital Anomaly or Birth Defect
AESDISAB text - Persist or Signif Disability/Incapacity
AESDTH text - Results in Death
AESHOSP text - Requires or Prolongs Hospitalization
AESLIFE text - Is Life Threatening
AESOD text - Occurred with Overdose
AEDTC date - Date/Time of Collection
AESTDTC date - Start Date/Time of Adverse Event
AEENDTC date - End Date/Time of Adverse Event
AESTDY integer - Study Day of Start of Adverse Event
AEENDY integer - Study Day of End of Adverse Event
Concomitant Medications data frame - One record per recorded medication occurrence or constant-dosing interval per subject
sdtm_cmsdtm_cm
a data frame with 7510 rows and 21 columns. See https://github.com/SafetyGraphics/safetyData/blob/main/data-raw/sdtm/README.md for more details and full data specification. Columns:
STUDYID text - Study Identifier
DOMAIN text - Domain Abbreviation
USUBJID text - Unique Subject Identifier
CMSEQ integer - Sequence Number
CMSPID text - Sponsor-Defined Identifier
CMTRT text - Reported Name of Drug, Med, or Therapy
CMDECOD text - Standardized Medication Name
CMINDC text - Indication
CMCLAS text - Medication Class
CMDOSE integer - Dose per Administration
CMDOSU text - Dose Units
CMDOSFRQ text - Dosing Frequency per Interval
CMROUTE text - Route of Administration
VISITNUM float - Visit Number
VISIT text - Visit Name
VISITDY integer - Planned Study Day of Visit
CMDTC date - Date/Time of Collection
CMSTDTC date - Start Date/Time of Medication
CMENDTC date - End Date/Time of Medication
CMSTDY integer - Study Day of Start of Medication
CMENDY integer - Study Day of End of Medication
Demographics data frame - One record per subject
sdtm_dmsdtm_dm
a data frame with 306 rows and 25 columns. See https://github.com/SafetyGraphics/safetyData/blob/main/data-raw/sdtm/README.md for more details and full data specification. Columns:
STUDYID text - Study Identifier
DOMAIN text - Domain Abbreviation
USUBJID text - Unique Subject Identifier
SUBJID text - Subject Identifier for the Study
RFSTDTC date - Subject Reference Start Date/Time
RFENDTC date - Subject Reference End Date/Time
RFXSTDTC datetime - Date/Time of First Study Treatment
RFXENDTC datetime - Date/Time of Last Study Treatment
RFICDTC datetime - Date/Time of Informed Consent
RFPENDTC datetime - Date/Time of End of Participation
DTHDTC datetime - Date/Time of Death
DTHFL text - Subject Death Flag
SITEID text - Study Site Identifier
AGE integer - Age
AGEU text - Age Units
SEX text - Sex
RACE text - Race
ETHNIC text - Ethnicity
ARMCD text - Planned Arm Code
ARM text - Description of Planned Arm
ACTARMCD text - Actual Arm Code
ACTARM text - Description of Actual Arm
COUNTRY text - Country
DMDTC date - Date/Time of Collection
DMDY integer - Study Day of Collection
Disposition data frame - One record per disposition status or protocol milestone per subject
sdtm_dssdtm_ds
a data frame with 596 rows and 13 columns. See https://github.com/SafetyGraphics/safetyData/blob/main/data-raw/sdtm/README.md for more details and full data specification. Columns:
STUDYID text - Study Identifier
DOMAIN text - Domain Abbreviation
USUBJID text - Unique Subject Identifier
DSSEQ integer - Sequence Number
DSSPID text - Sponsor-Defined Identifier
DSTERM text - Reported Term for the Disposition Event
DSDECOD text - Standardized Disposition Term
DSCAT text - Category for Disposition Event
VISITNUM float - Visit Number
VISIT text - Visit Name
DSDTC datetime - Date/Time of Collection
DSSTDTC date - Start Date/Time of Disposition Event
DSSTDY integer - Study Day of Start of Disposition Event
Exposure data frame - One record per constant dosing interval per subject
sdtm_exsdtm_ex
a data frame with 591 rows and 17 columns. See https://github.com/SafetyGraphics/safetyData/blob/main/data-raw/sdtm/README.md for more details and full data specification. Columns:
STUDYID text - Study Identifier
DOMAIN text - Domain Abbreviation
USUBJID text - Unique Subject Identifier
EXSEQ integer - Sequence Number
EXTRT text - Name of Actual Treatment
EXDOSE integer - Dose per Administration
EXDOSU text - Dose Units
EXDOSFRM text - Dose Form
EXDOSFRQ text - Dosing Frequency per Interval
EXROUTE text - Route of Administration
VISITNUM float - Visit Number
VISIT text - Visit Name
VISITDY integer - Planned Study Day of Visit
EXSTDTC date - Start Date/Time of Treatment
EXENDTC date - End Date/Time of Treatment
EXSTDY integer - Study Day of Start of Treatment
EXENDY integer - Study Day of End of Treatment
Laboratory Tests Results data frame - One record per analyte per planned time point number per time point reference per visit per subject
sdtm_lbsdtm_lb
a data frame with 59580 rows and 23 columns. See https://github.com/SafetyGraphics/safetyData/blob/main/data-raw/sdtm/README.md for more details and full data specification. Columns:
STUDYID text - Study Identifier
DOMAIN text - Domain Abbreviation
USUBJID text - Unique Subject Identifier
LBSEQ integer - Sequence Number
LBTESTCD text - Lab Test or Examination Short Name
LBTEST text - Lab Test or Examination Name
LBCAT text - Category for Lab Test
LBORRES text - Result or Finding in Original Units
LBORRESU text - Original Units
LBORNRLO text - Reference Range Lower Limit in Orig Unit
LBORNRHI text - Reference Range Upper Limit in Orig Unit
LBSTRESC text - Character Result/Finding in Std Format
LBSTRESN integer - Numeric Result/Finding in Standard Units
LBSTRESU text - Standard Units
LBSTNRLO integer - Reference Range Lower Limit-Std Units
LBSTNRHI integer - Reference Range Upper Limit-Std Units
LBNRIND text - Reference Range Indicator
LBBLFL text - Baseline Flag
VISITNUM float - Visit Number
VISIT text - Visit Name
VISITDY integer - Planned Study Day of Visit
LBDTC datetime - Date/Time of Specimen Collection
LBDY integer - Study Day of Specimen Collection
Medical History data frame - One record per medical history event per subject
sdtm_mhsdtm_mh
a data frame with 1818 rows and 19 columns. See https://github.com/SafetyGraphics/safetyData/blob/main/data-raw/sdtm/README.md for more details and full data specification. Columns:
STUDYID text - Study Identifier
DOMAIN text - Domain Abbreviation
USUBJID text - Unique Subject Identifier
MHSEQ integer - Sequence Number
MHSPID text - Sponsor-Defined Identifier
MHTERM text - Reported Term for the Medical History
MHLLT text - Lowest Level Term
MHDECOD text - Dictionary-Derived Term
MHHLT text - High Level Term
MHHLGT text - High Level Group Term
MHCAT text - Category for Medical History
MHBODSYS text - Body System or Organ Class
MHSEV text - Severity/Intensity
VISITNUM float - Visit Number
VISIT text - Visit Name
VISITDY integer - Planned Study Day of Visit
MHDTC date - Date/Time of History Collection
MHSTDTC date - Start Date/Time of Medical History Event
MHDY integer - Study Day of History Collection
Questionnaires data frame - One record per questionnaire per question per time point per visit per subject
sdtm_qssdtm_qs
a data frame with 121749 rows and 20 columns. See https://github.com/SafetyGraphics/safetyData/blob/main/data-raw/sdtm/README.md for more details and full data specification. Columns:
STUDYID text - Study Identifier
DOMAIN text - Domain Abbreviation
USUBJID text - Unique Subject Identifier
QSSEQ integer - Sequence Number
QSTESTCD text - Question Short Name
QSTEST text - Question Name
QSCAT text - Category of Question
QSSCAT text - Subcategory for Question
QSORRES text - Finding in Original Units
QSORRESU text - Original Units
QSSTRESC text - Character Result/Finding in Std Format
QSSTRESN integer - Numeric Finding in Standard Units
QSSTRESU text - Standard Units
QSBLFL text - Baseline Flag
QSDRVFL text - Derived Flag
VISITNUM float - Visit Number
VISIT text - Visit Name
VISITDY integer - Planned Study Day of Visit
QSDTC date - Date/Time of Finding
QSDY integer - Study Day of Finding
Related Records data frame - One record per related record, group of records or datasets
sdtm_relrecsdtm_relrec
a data frame with 234 rows and 7 columns. See https://github.com/SafetyGraphics/safetyData/blob/main/data-raw/sdtm/README.md for more details and full data specification. Columns:
STUDYID text - Study Identifier
RDOMAIN text - Related Domain Abbreviation
USUBJID text - Unique Subject Identifier
IDVAR text - Identifying Variable
IDVARVAL text - Identifying Variable Value
RELTYPE text - Relationship Type
RELID text - Relationship Identifier
Subject Characteristics data frame - One record per characteristic per subject
sdtm_scsdtm_sc
a data frame with 254 rows and 14 columns. See https://github.com/SafetyGraphics/safetyData/blob/main/data-raw/sdtm/README.md for more details and full data specification. Columns:
STUDYID text - Study Identifier
DOMAIN text - Domain Abbreviation
USUBJID text - Unique Subject Identifier
SCSEQ integer - Sequence Number
SCTESTCD text - Subject Characteristic Short Name
SCTEST text - Subject Characteristic
SCCAT text - Category for Subject Characteristic
SCORRES text - Result or Finding in Original Units
SCORRESU text - Original Units
SCSTRESC text - Character Result/Finding in Std Format
SCSTRESN integer - Numeric Result/Finding in Standard Units
SCSTRESU text - Standard Units
SCDTC date - Date/Time of Collection
SCDY integer - Study Day of Examination
Subject Elements data frame - One record per actual Element per subject
sdtm_sesdtm_se
a data frame with 752 rows and 9 columns. See https://github.com/SafetyGraphics/safetyData/blob/main/data-raw/sdtm/README.md for more details and full data specification. Columns:
STUDYID text - Study Identifier
DOMAIN text - Domain Abbreviation
USUBJID text - Unique Subject Identifier
SESEQ integer - Sequence Number
ETCD text - Element Code
ELEMENT text - Description of Element
SESTDTC date - Start Date/Time of Element
SEENDTC date - End Date/Time of Element
SEUPDES text - Description of Unplanned Element
Supplemental Qualifiers for AE data frame - One record per IDVAR, IDVARVAL, and QNAM value per subject
sdtm_suppaesdtm_suppae
a data frame with 1191 rows and 10 columns. See https://github.com/SafetyGraphics/safetyData/blob/main/data-raw/sdtm/README.md for more details and full data specification. Columns:
STUDYID text - Study Identifier
RDOMAIN text - Related Domain Abbreviation
USUBJID text - Unique Subject Identifier
IDVAR text - Identifying Variable
IDVARVAL text - Identifying Variable Value
QNAM text - Qualifier Variable Name
QLABEL text - Qualifier Variable Label
QVAL text - Data Value
QORIG text - Origin
QEVAL text - Evaluator
Supplemental Qualifiers for DM data frame - One record per IDVAR, IDVARVAL, and QNAM value per subject
sdtm_suppdmsdtm_suppdm
a data frame with 1197 rows and 10 columns. See https://github.com/SafetyGraphics/safetyData/blob/main/data-raw/sdtm/README.md for more details and full data specification. Columns:
STUDYID text - Study Identifier
RDOMAIN text - Related Domain Abbreviation
USUBJID text - Unique Subject Identifier
IDVAR text - Identifying Variable
IDVARVAL text - Identifying Variable Value
QNAM text - Qualifier Variable Name
QLABEL text - Qualifier Variable Label
QVAL text - Data Value
QORIG text - Origin
QEVAL text - Evaluator
Supplemental Qualifiers for DS data frame - One record per IDVAR, IDVARVAL, and QNAM value per subject
sdtm_suppdssdtm_suppds
a data frame with 3 rows and 10 columns. See https://github.com/SafetyGraphics/safetyData/blob/main/data-raw/sdtm/README.md for more details and full data specification. Columns:
STUDYID text - Study Identifier
RDOMAIN text - Related Domain Abbreviation
USUBJID text - Unique Subject Identifier
IDVAR text - Identifying Variable
IDVARVAL text - Identifying Variable Value
QNAM text - Qualifier Variable Name
QLABEL text - Qualifier Variable Label
QVAL text - Data Value
QORIG text - Origin
QEVAL text - Evaluator
Supplemental Qualifiers for LB data frame - One record per IDVAR, IDVARVAL, and QNAM value per subject
sdtm_supplbsdtm_supplb
a data frame with 64403 rows and 10 columns. See https://github.com/SafetyGraphics/safetyData/blob/main/data-raw/sdtm/README.md for more details and full data specification. Columns:
STUDYID text - Study Identifier
RDOMAIN text - Related Domain Abbreviation
USUBJID text - Unique Subject Identifier
IDVAR text - Identifying Variable
IDVARVAL text - Identifying Variable Value
QNAM text - Qualifier Variable Name
QLABEL text - Qualifier Variable Label
QVAL text - Data Value
QORIG text - Origin
QEVAL text - Evaluator
Subject Visits data frame - One record per actual visit per subject
sdtm_svsdtm_sv
a data frame with 3559 rows and 8 columns. See https://github.com/SafetyGraphics/safetyData/blob/main/data-raw/sdtm/README.md for more details and full data specification. Columns:
STUDYID text - Study Identifier
DOMAIN text - Domain Abbreviation
USUBJID text - Unique Subject Identifier
VISITNUM float - Visit Number
VISIT text - Visit Name
VISITDY integer - Planned Study Day of Visit
SVSTDTC date - Start Date/Time of Visit
SVENDTC date - End Date/Time of Visit
Trial Arms data frame - One record per planned Element per Arm
sdtm_tasdtm_ta
a data frame with 8 rows and 10 columns. See https://github.com/SafetyGraphics/safetyData/blob/main/data-raw/sdtm/README.md for more details and full data specification. Columns:
STUDYID text - Study Identifier
DOMAIN text - Domain Abbreviation
ARMCD text - Planned Arm Code
ARM text - Description of Planned Arm
TAETORD integer - Order of Element within Arm
ETCD text - Element Code
ELEMENT text - Description of Element
TABRANCH text - Branch
TATRANS text - Transition Rule
EPOCH text - Epoch
Trial Elements data frame - One record per planned Element
sdtm_tesdtm_te
a data frame with 7 rows and 7 columns. See https://github.com/SafetyGraphics/safetyData/blob/main/data-raw/sdtm/README.md for more details and full data specification. Columns:
STUDYID text - Study Identifier
DOMAIN text - Domain Abbreviation
ETCD text - Element Code
ELEMENT text - Description of Element
TESTRL text - Rule for Start of Element
TEENRL text - Rule for End of Element
TEDUR text - Planned Duration of Element
Trial Inclusion/ Exclusion Criteria data frame - One record per I/E criterion
sdtm_tisdtm_ti
a data frame with 31 rows and 6 columns. See https://github.com/SafetyGraphics/safetyData/blob/main/data-raw/sdtm/README.md for more details and full data specification. Columns:
STUDYID text - Study Identifier
DOMAIN text - Domain Abbreviation
IETESTCD text - Incl/Excl Criterion Short Name
IETEST text - Inclusion/Exclusion Criterion
IECAT text - Inclusion/Exclusion Category
TIRL text - Inclusion/Exclusion Criterion Rule
Trial Summary data frame - One record per trial summary parameter value
sdtm_tssdtm_ts
a data frame with 33 rows and 6 columns. See https://github.com/SafetyGraphics/safetyData/blob/main/data-raw/sdtm/README.md for more details and full data specification. Columns:
STUDYID text - Study Identifier
DOMAIN text - Domain Abbreviation
TSSEQ integer - Sequence Number
TSPARMCD text - Trial Summary Parameter Short Name
TSPARM text - Trial Summary Parameter
TSVAL text - Parameter Value
Trial Visits data frame - One record per planned Visit per Arm
sdtm_tvsdtm_tv
a data frame with 21 rows and 9 columns. See https://github.com/SafetyGraphics/safetyData/blob/main/data-raw/sdtm/README.md for more details and full data specification. Columns:
STUDYID text - Study Identifier
DOMAIN text - Domain Abbreviation
VISITNUM float - Visit Number
VISIT text - Visit Name
VISITDY integer - Planned Study Day of Visit
ARMCD text - Planned Arm Code
ARM text - Description of Planned Arm
TVSTRL text - Visit Start Rule
TVENRL text - Visit End Rule
Vital Signs data frame - One record per vital sign measurement per time point per visit per subject
sdtm_vssdtm_vs
a data frame with 29643 rows and 24 columns. See https://github.com/SafetyGraphics/safetyData/blob/main/data-raw/sdtm/README.md for more details and full data specification. Columns:
STUDYID text - Study Identifier
DOMAIN text - Domain Abbreviation
USUBJID text - Unique Subject Identifier
VSSEQ integer - Sequence Number
VSTESTCD text - Vital Signs Test Short Name
VSTEST text - Vital Signs Test Name
VSPOS text - Vital Signs Position of Subject
VSORRES text - Result or Finding in Original Units
VSORRESU text - Original Units
VSSTRESC text - Character Result/Finding in Std Format
VSSTRESN integer - Numeric Result/Finding in Standard Units
VSSTRESU text - Standard Units
VSSTAT text - Completion Status
VSLOC text - Location of Vital Signs Measurement
VSBLFL text - Baseline Flag
VISITNUM float - Visit Number
VISIT text - Visit Name
VISITDY integer - Planned Study Day of Visit
VSDTC date - Date/Time of Measurements
VSDY integer - Study Day of Vital Signs
VSTPT text - Planned Time Point Name
VSTPTNUM integer - Planned Time Point Number
VSELTM text - Planned Elapsed Time from Time Point Ref
VSTPTREF text - Time Point Reference